BufferedInput

Struct BufferedInput 

pub struct BufferedInput<T: Iterator<Item = char>> { /* private fields */ }
A wrapper around an Iterator of chars with a buffer.

The YAML scanner often needs some lookahead. With fully allocated buffers such as String or &str, this is not an issue. However, with streams, we need to have a way of peeking multiple characters at a time and sometimes pushing some back into the stream. Doing this directly with iterator adapters would require pulling in all of itertools for one method, so this structure keeps the buffering local.

Implementations

Source

impl<T: Iterator<Item = char>> BufferedInput<T>

pub fn new(input: T) -> Self

Create a new BufferedInput over the given character iterator.