pub struct FallibleBufferedInput<T: Iterator<Item = Result<char, ErrorKind>>> { /* private fields */ }Expand description
A buffered wrapper around a fallible iterator of characters.
The iterator uses its normal None return value for clean end-of-input and returns source
failures as Some(Err(error)), where error is an ErrorKind. The first error is latched,
parsing becomes terminal, and the underlying iterator is never polled again.
Implementations