pub struct ScanError { /* private fields */ }Expand description
An error that occurred while reading, scanning, or parsing YAML.
Implementations
Sourceimpl ScanError
impl ScanError
Sourcepub fn new(loc: Marker, message: impl Into<String>) -> ScanError
pub fn new(loc: Marker, message: impl Into<String>) -> ScanError
Create an externally supplied error from a location and message.
The message is stored in ErrorKind::Custom. This is useful for adapters that
participate in parser APIs, such as a custom ParserTrait
implementation or a ParserStack include resolver.
Sourcepub fn try_into_input_io_error(self) -> Result<InputIoError, Self>
pub fn try_into_input_io_error(self) -> Result<InputIoError, Self>
Extract the input I/O error details without cloning them.
Errors
Returns the original scan error unchanged when it has a different error category.
Sourcepub fn source_stack(&self) -> &[String]
pub fn source_stack(&self) -> &[String]
Return source names captured by a parser stack, from bottom to top.