pub struct Token<'input>(/* private fields */);Expand description
A scanner token.
Implementations
Sourceimpl<'input> Token<'input>
impl<'input> Token<'input>
Sourcepub const fn new(span: Span, token_type: TokenType<'input>) -> Self
pub const fn new(span: Span, token_type: TokenType<'input>) -> Self
Create a scanner token from its source span and payload.
Sourcepub const fn token_type(&self) -> &TokenType<'input>
pub const fn token_type(&self) -> &TokenType<'input>
Return the payload emitted by the scanner.
Sourcepub fn into_parts(self) -> (Span, TokenType<'input>)
pub fn into_parts(self) -> (Span, TokenType<'input>)
Consume the token and return its source span and payload.