TryEventReceiver

Trait TryEventReceiver 

pub trait TryEventReceiver<'input> {
    type Error;

    // Required method
    fn on_event(&mut self, ev: Event<'input>) -> Result<(), Self::Error>;
}
Trait to be implemented for fallible event handling without source spans.

This is the fallible counterpart to EventReceiver. Use it with Parser::try_load when event handling may need to stop parsing by returning an application error.

Required Associated Types

type Error

Error returned by this receiver.

Required Methods

fn on_event(&mut self, ev: Event<'input>) -> Result<(), Self::Error>

Handler called for each YAML event that is emitted by the parser.

Returning an error stops Parser::try_load immediately.

Errors

Returns Self::Error when the receiver wants to stop parsing.

Implementors