pub trait SpannedEventReceiver<'input> {
// Required method
fn on_event(&mut self, ev: Event<'input>, span: Span);
}Expand description
Trait to be implemented for using the low-level parsing API.
Functionally similar to EventReceiver, but receives a Span as well as the event.
For Event::Comment, the span is the source range of the whole comment.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".