pub trait TryEventReceiver<'input> {
type Error;
// Required method
fn on_event(&mut self, ev: Event<'input>) -> Result<(), Self::Error>;
}Expand description
Trait to be implemented for fallible event handling without source spans.
This is the fallible counterpart to EventReceiver. Use it with Parser::try_load when
event handling may need to stop parsing by returning an application error.